<?php

declare(strict_types=1);

namespace Dedi\SyliusMailAdminPlugin\Form\Constraints;

use Dedi\SyliusMailAdminPlugin\Checker\MailVariablesValidatorInterface;
use Dedi\SyliusMailAdminPlugin\Exception\UnexpectedMailVariablesException;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

class AvailableVariablesValidator extends ConstraintValidator
{
    private MailVariablesValidatorInterface $mailVariablesValidator;

    public function __construct(MailVariablesValidatorInterface $mailVariablesValidator)
    {
        $this->mailVariablesValidator = $mailVariablesValidator;
    }

    /**
     * @param mixed $value
     * @param AvailableVariables $constraint
     */
    public function validate($value, Constraint $constraint): void
    {
        if (empty($value)) {
            return;
        }

        try {
            $this->mailVariablesValidator->validateMailVariables($constraint->mailCode, $value);
        } catch (UnexpectedMailVariablesException $e) {
            $this->context->addViolation($e->getMessage());
        }
    }
}
